//FEAT Create new category
import type IDbCategory from "@interfaces/database/IDbCategory";
import { v4 as uuidv4 } from 'uuid';
import {Logger} from "tslog";
import MysqlService from "@services/mysql.service";

const DbHandler = new MysqlService.Handler('CategoryService')
const logger = new Logger({name: 'CategoryService'})



/**
 * Creates a new category with the given data.
 *
 * @param {IDbCategory} data - The category data.
 * @returns {Promise<unknown>} A promise that resolves with the created category.
 *                            If an error occurs, the promise will reject with the error.
 */
async function createCategory(data: IDbCategory): Promise<unknown> {
	logger.info(`Creating a new category... (${data.display_name})`)
	try {
		return await MysqlService.Category.insert(DbHandler, {
			id: uuidv4(),
			display_name: data.display_name,
			slug_name: data.slug_name
		})
	} catch (error) {
		logger.error(`Error creating category: ${error}`);
    return;
	}
}

/**
 * Retrieves all categories from the database.
 *
 * @returns {Promise<Array<IDbCategory>> | null} Promise that resolves to an array of IDbCategory objects or null if an error occurred.
 */
async function getAll(): Promise<Promise<Array<IDbCategory>> | null> {
	try {
			logger.info("Getting all categories...");
      return await MysqlService.Category.getAll(DbHandler);
  } catch (error) {
      logger.error(`Error getting all categories: ${error}`);
      return null;
  }
}

//FEAT Get a category (slug)
async function getBySlug(slug: string) {
	try {
    logger.info(`Getting category by slug... (${slug})`);
    return await MysqlService.Category.getBySlug(DbHandler, slug);
  } catch (error) {
    logger.error(`Error getting category by slug: ${error}`);
    return null;
  }
}

//FEAT Get a category (id)

//FEAT Get all models in category (slug)

//FEAT Delete a category (id)

const CategoryService = {
	create: createCategory,
	getAll,
	getBySlug
}

export default CategoryService;